==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/OperationMetricFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OperationMetricFluent<A extends OperationMetricFluent<A>> extends BaseFluent<A>{
  public OperationMetricFluent() {
  }
  
  public OperationMetricFluent(OperationMetric instance) {
    this.copyInstance(instance);
  }
  private String end;
  private String start;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OperationMetric instance) {
    instance = (instance != null ? instance : new OperationMetric());
  
    if (instance != null) {
        this.withEnd(instance.getEnd());
        this.withStart(instance.getStart());
        this.withEnd(instance.getEnd());
        this.withStart(instance.getStart());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getEnd() {
    return this.end;
  }
  
  public A withEnd(String end) {
    this.end=end; return (A) this;
  }
  
  public boolean hasEnd() {
    return this.end != null;
  }
  
  public String getStart() {
    return this.start;
  }
  
  public A withStart(String start) {
    this.start=start; return (A) this;
  }
  
  public boolean hasStart() {
    return this.start != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperationMetricFluent that = (OperationMetricFluent) o;
    if (!java.util.Objects.equals(end, that.end)) return false;
  
    if (!java.util.Objects.equals(start, that.start)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(end,  start,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (end != null) { sb.append("end:"); sb.append(end + ","); }
    if (start != null) { sb.append("start:"); sb.append(start + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/OperationMetricFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OperationMetricFluent<A extends OperationMetricFluent<A>> extends BaseFluent<A>{
  public OperationMetricFluent() {
  }
  
  public OperationMetricFluent(OperationMetric instance) {
    this.copyInstance(instance);
  }
  private String end;
  private String start;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OperationMetric instance) {
    instance = (instance != null ? instance : new OperationMetric());
    if (instance != null) {
          this.withEnd(instance.getEnd());
          this.withStart(instance.getStart());
          this.withEnd(instance.getEnd());
          this.withStart(instance.getStart());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getEnd() {
    return this.end;
  }
  
  public A withEnd(String end) {
    this.end = end;
    return (A) this;
  }
  
  public boolean hasEnd() {
    return this.end != null;
  }
  
  public String getStart() {
    return this.start;
  }
  
  public A withStart(String start) {
    this.start = start;
    return (A) this;
  }
  
  public boolean hasStart() {
    return this.start != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperationMetricFluent that = (OperationMetricFluent) o;
    if (!java.util.Objects.equals(end, that.end)) return false;
    if (!java.util.Objects.equals(start, that.start)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(end,  start,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (end != null) { sb.append("end:"); sb.append(end + ","); }
    if (start != null) { sb.append("start:"); sb.append(start + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
